@@ -75,42 +75,45 @@ class DasTuner(kt.Tuner):
                   epochs=10, steps_per_epoch=None,
                   verbose=1, class_weight=None,
                   callbacks=None):
-        if callbacks is None:
-            callbacks = []
-        callbacks.append(OracleCallback(self))
+        try:
+            if callbacks is None:
+                callbacks = []
+            callbacks.append(OracleCallback(self))
 
-        self.params.update(trial.hyperparameters.values)
-        self.current_trial = trial
+            self.params.update(trial.hyperparameters.values)
+            self.current_trial = trial
 
-        # these need updating based on current hyperparameters
-        self.params['stride'] = self.params['nb_hist']
-        if self.params['ignore_boundaries']:
-            self.params['data_padding'] = int(np.ceil(self.params['kernel_size'] * self.params['nb_conv']))  # this does not completely avoid boundary effects but should minimize them sufficiently
-            self.params['stride'] = self.params['stride'] - 2 * self.params['data_padding']
+            # these need updating based on current hyperparameters
+            self.params['stride'] = self.params['nb_hist']
+            if self.params['ignore_boundaries']:
+                self.params['data_padding'] = int(np.ceil(self.params['kernel_size'] * self.params['nb_conv']))  # this does not completely avoid boundary effects but should minimize them sufficiently
+                self.params['stride'] = self.params['stride'] - 2 * self.params['data_padding']
 
-        data_gen = data.AudioSequence(train_x, train_y,
-                                      shuffle=True, nb_repeats=1,
-                                      last_sample=train_x.shape[0] - 2 * self.params['nb_hist'],
-                                      **self.params)
-        val_gen = data.AudioSequence(val_x, val_y,
-                                     shuffle=False,
-                                     **self.params)
-        logging.info("Data:")
-        logging.info(f"training: {data_gen}")
-        logging.info(f"validation: {val_gen}")
+            data_gen = data.AudioSequence(train_x, train_y,
+                                          shuffle=True, nb_repeats=1,
+                                          last_sample=train_x.shape[0] - 2 * self.params['nb_hist'],
+                                          **self.params)
+            val_gen = data.AudioSequence(val_x, val_y,
+                                         shuffle=False,
+                                         **self.params)
+            logging.info("Data:")
+            logging.info(f"training: {data_gen}")
+            logging.info(f"validation: {val_gen}")
 
-        logging.info("Hyperparameters:")
-        logging.info(trial.hyperparameters.values)
-        if steps_per_epoch is None:
-            steps_per_epoch = min(len(data_gen), 1000)
+            logging.info("Hyperparameters:")
+            logging.info(trial.hyperparameters.values)
+            if steps_per_epoch is None:
+                steps_per_epoch = min(len(data_gen), 1000)
 
-        model = self.hypermodel.build(trial.hyperparameters)
-        model.fit(data_gen, validation_data=val_gen, epochs=epochs, steps_per_epoch=steps_per_epoch,
-                  callbacks=callbacks, verbose=verbose, class_weight=class_weight)
+            model = self.hypermodel.build(trial.hyperparameters)
+            model.fit(data_gen, validation_data=val_gen, epochs=epochs, steps_per_epoch=steps_per_epoch,
+                      callbacks=callbacks, verbose=verbose, class_weight=class_weight)
+        except:
+            logging.exception("Something went wrong. Will try to continue.")
 
 
 def train(*, data_dir: str, x_suffix: str = '', y_suffix: str = '',
-          save_dir: str = './', save_prefix: Optional[str] = None,
+          save_dir: str = './', save_prefix: Optional[str] = None, save_name: Optional[str] = None,
           model_name: str = 'tcn', nb_filters: int = 16, kernel_size: int = 16,
           nb_conv: int = 3, use_separable: List[bool] = False, nb_hist: int = 1024,
           ignore_boundaries: bool = True, batch_norm: bool = True,
@@ -145,6 +148,11 @@ def train(*, data_dir: str, x_suffix: str = '', y_suffix: str = '',
                            Name of files created will be start with SAVE_DIR/SAVE_PREFIX + "_" + TIMESTAMP
                            or with SAVE_DIR/TIMESTAMP if SAVE_PREFIX is empty.
                            Defaults to '' (empty).
+        save_name (Optional[str]): Append to prefix.
+                           Name of files created will be start with SAVE_DIR/SAVE_PREFIX + "_" + SAVE_NAME
+                           or with SAVE_DIR/SAVE_NAME if SAVE_PREFIX is empty.
+                           Defaults to TIMESTAMP.
+
         model_name (str): Network architecture to use.
                           Use `tcn` (TCN) or `tcn_stft` (TCN with STFT frontend).
                           See das.models for a description of all models.
@@ -325,11 +333,13 @@ def train(*, data_dir: str, x_suffix: str = '', y_suffix: str = '',
     logging.info('building network')
 
     os.makedirs(os.path.abspath(save_dir), exist_ok=True)
-    save_name = '{0}/{1}{2}'.format(save_dir, save_prefix, time.strftime('%Y%m%d_%H%M%S'))
+    if save_name is None:
+        save_name = time.strftime('%Y%m%d_%H%M%S')
+    save_name = '{0}/{1}{2}'.format(save_dir, save_prefix, save_name)
     logging.info(f'Will save to {save_name}.')
 
     tuner = DasTuner(
-        params = params,
+        params=params,
         oracle=kt.oracles.BayesianOptimization(
             objective=kt.Objective("val_loss", "min"), max_trials=100,
         ),
@@ -403,14 +413,14 @@ def train(*, data_dir: str, x_suffix: str = '', y_suffix: str = '',
         save_filename = "{0}_results.h5".format(save_name)
         logging.info('saving to ' + save_filename + '.')
         d = {'fit_hist': fit_hist.history,
-            'confusion_matrix': conf_mat,
-            'classification_report': report,
-            'x_test': x_test,
-            'y_test': y_test,
-            'y_pred': y_pred,
-            'labels_test': labels_test,
-            'labels_pred': labels_pred,
-            'params': params,
+             'confusion_matrix': conf_mat,
+             'classification_report': report,
+             'x_test': x_test,
+             'y_test': y_test,
+             'y_pred': y_pred,
+             'labels_test': labels_test,
+             'labels_pred': labels_pred,
+             'params': params,
             }
 
         fl.save(save_filename, d)
